==> jc-1.4.0.tar.gz: gnu/xml/transform/NodeNumberNode.h <==
// final class gnu.xml.transform.NodeNumberNode

// class file dependencies
// @dep_class 51c9cbf326b4d63b gnu_xml_transform_AbstractNumberNode
// @dep_class 208dc5d7df5d324f gnu_xml_transform_NodeNumberNode
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_transform_AbstractNumberNode

#include "gnu/xml/transform/AbstractNumberNode.h"

#ifndef _JC_gnu_xml_transform_NodeNumberNode_H_
#define _JC_gnu_xml_transform_NodeNumberNode_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_gnu_xml_xpath_Pattern$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_NodeNumberNode$sub_refs	_jc_gnu_xml_transform_NodeNumberNode$sub_refs;
typedef struct _jc_gnu_xml_transform_NodeNumberNode$sub_nonrefs	_jc_gnu_xml_transform_NodeNumberNode$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_NodeNumberNode$refs	_jc_gnu_xml_transform_NodeNumberNode$refs;
typedef struct _jc_gnu_xml_transform_NodeNumberNode$nonrefs	_jc_gnu_xml_transform_NodeNumberNode$nonrefs;
typedef struct _jc_gnu_xml_transform_NodeNumberNode$object	_jc_gnu_xml_transform_NodeNumberNode$object;

typedef struct _jc_gnu_xml_transform_NodeNumberNode$fields_struct	_jc_gnu_xml_transform_NodeNumberNode$fields_struct;
typedef const struct _jc_gnu_xml_transform_NodeNumberNode$vmethods	_jc_gnu_xml_transform_NodeNumberNode$vmethods;
typedef const struct _jc_gnu_xml_transform_NodeNumberNode$vtable	_jc_gnu_xml_transform_NodeNumberNode$vtable;
typedef const struct _jc_gnu_xml_transform_NodeNumberNode$vtype	_jc_gnu_xml_transform_NodeNumberNode$vtype;

// Class fields structure
struct _jc_gnu_xml_transform_NodeNumberNode$fields_struct {
	jint	ANY;
	jint	MULTIPLE;
	jint	SINGLE;
};
extern _jc_gnu_xml_transform_NodeNumberNode$fields_struct _jc_gnu_xml_transform_NodeNumberNode$class_fields;

// Constructors
extern void _jc_gnu_xml_transform_NodeNumberNode$method$_init$bc48f42985848680(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, jint, struct _jc_gnu_xml_xpath_Pattern$object *, struct _jc_gnu_xml_xpath_Pattern$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern struct _jc_gnu_xml_transform_TemplateNode$object *_jc_gnu_xml_transform_NodeNumberNode$method$clone$b8a038f4254cb648(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
extern _jc_int_array *_jc_gnu_xml_transform_NodeNumberNode$method$compute$51e66c80abac24fa(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_object *, jint, jint);
extern jboolean _jc_gnu_xml_transform_NodeNumberNode$method$countMatches$09e866abd4fb4dcb(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_object *, struct _jc_object *);
extern jboolean _jc_gnu_xml_transform_NodeNumberNode$method$fromMatches$d09ae2cf157ddd0f(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_object *);
extern jint _jc_gnu_xml_transform_NodeNumberNode$method$getIndex$b9d463639d011209(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_NodeNumberNode$method_info$clone$b8a038f4254cb648;
extern _jc_method _jc_gnu_xml_transform_NodeNumberNode$method_info$compute$51e66c80abac24fa;
extern _jc_method _jc_gnu_xml_transform_NodeNumberNode$method_info$countMatches$09e866abd4fb4dcb;
extern _jc_method _jc_gnu_xml_transform_NodeNumberNode$method_info$fromMatches$d09ae2cf157ddd0f;
extern _jc_method _jc_gnu_xml_transform_NodeNumberNode$method_info$getIndex$b9d463639d011209;

// Virtual methods structure
struct _jc_gnu_xml_transform_NodeNumberNode$vmethods {
	struct _jc_gnu_xml_transform_TemplateNode$object	*(*clone$b8a038f4254cb648)(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
	_jc_int_array	*(*compute$51e66c80abac24fa)(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_object *, jint, jint);
	jboolean	(*countMatches$09e866abd4fb4dcb)(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_object *, struct _jc_object *);
	jboolean	(*fromMatches$d09ae2cf157ddd0f)(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_object *);
	jint	(*getIndex$b9d463639d011209)(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_xml_transform_NodeNumberNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplateNode$vmethods	gnu_xml_transform_TemplateNode;
	_jc_gnu_xml_transform_AbstractNumberNode$vmethods	gnu_xml_transform_AbstractNumberNode;
	_jc_gnu_xml_transform_NodeNumberNode$vmethods	gnu_xml_transform_NodeNumberNode;
};

// Vtype
struct _jc_gnu_xml_transform_NodeNumberNode$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_NodeNumberNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_NodeNumberNode$sub_refs {
	struct _jc_gnu_xml_xpath_Pattern$object	*count;
	struct _jc_gnu_xml_xpath_Pattern$object	*from;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_NodeNumberNode$refs {
    _jc_gnu_xml_transform_NodeNumberNode$sub_refs	gnu_xml_transform_NodeNumberNode;
    _jc_gnu_xml_transform_AbstractNumberNode$sub_refs	gnu_xml_transform_AbstractNumberNode;
    _jc_gnu_xml_transform_TemplateNode$sub_refs	gnu_xml_transform_TemplateNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_NodeNumberNode$sub_nonrefs {
	jint	level;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_NodeNumberNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	gnu_xml_transform_TemplateNode;
    _jc_gnu_xml_transform_AbstractNumberNode$sub_nonrefs	gnu_xml_transform_AbstractNumberNode;
    _jc_gnu_xml_transform_NodeNumberNode$sub_nonrefs	gnu_xml_transform_NodeNumberNode;
};

// Object instance structure
struct _jc_gnu_xml_transform_NodeNumberNode$object {
	_jc_gnu_xml_transform_NodeNumberNode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_NodeNumberNode$vtype	*vtype;
	_jc_gnu_xml_transform_NodeNumberNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_NodeNumberNode$vtype _jc_gnu_xml_transform_NodeNumberNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_NodeNumberNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_NodeNumberNode$class_object;

#endif	/* _JC_gnu_xml_transform_NodeNumberNode_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/transform/NodeNumberNode.h <==
// final class gnu.xml.transform.NodeNumberNode

// class file dependencies
// @dep_class 51c9cbf326b4d63b gnu_xml_transform_AbstractNumberNode
// @dep_class 208dc5d7df5d324f gnu_xml_transform_NodeNumberNode
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_transform_AbstractNumberNode

#include "gnu/xml/transform/AbstractNumberNode.h"

#ifndef _JC_gnu_xml_transform_NodeNumberNode_H_
#define _JC_gnu_xml_transform_NodeNumberNode_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_gnu_xml_xpath_Pattern$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_NodeNumberNode$sub_refs	_jc_gnu_xml_transform_NodeNumberNode$sub_refs;
typedef struct _jc_gnu_xml_transform_NodeNumberNode$sub_nonrefs	_jc_gnu_xml_transform_NodeNumberNode$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_NodeNumberNode$refs	_jc_gnu_xml_transform_NodeNumberNode$refs;
typedef struct _jc_gnu_xml_transform_NodeNumberNode$nonrefs	_jc_gnu_xml_transform_NodeNumberNode$nonrefs;
typedef struct _jc_gnu_xml_transform_NodeNumberNode$object	_jc_gnu_xml_transform_NodeNumberNode$object;

typedef struct _jc_gnu_xml_transform_NodeNumberNode$fields_struct	_jc_gnu_xml_transform_NodeNumberNode$fields_struct;
typedef const struct _jc_gnu_xml_transform_NodeNumberNode$vmethods	_jc_gnu_xml_transform_NodeNumberNode$vmethods;
typedef const struct _jc_gnu_xml_transform_NodeNumberNode$vtable	_jc_gnu_xml_transform_NodeNumberNode$vtable;
typedef const struct _jc_gnu_xml_transform_NodeNumberNode$vtype	_jc_gnu_xml_transform_NodeNumberNode$vtype;

// Class fields structure
struct _jc_gnu_xml_transform_NodeNumberNode$fields_struct {
	jint	ANY;
	jint	MULTIPLE;
	jint	SINGLE;
};
extern _jc_gnu_xml_transform_NodeNumberNode$fields_struct _jc_gnu_xml_transform_NodeNumberNode$class_fields;

// Constructors
extern void _jc_gnu_xml_transform_NodeNumberNode$method$_init$bc48f42985848680(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, jint, struct _jc_gnu_xml_xpath_Pattern$object *, struct _jc_gnu_xml_xpath_Pattern$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_transform_TemplateNode$object *_jc_gnu_xml_transform_NodeNumberNode$method$clone$b8a038f4254cb648(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
extern _jc_int_array *_jc_gnu_xml_transform_NodeNumberNode$method$compute$51e66c80abac24fa(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_transform_NodeNumberNode$method$countMatches$09e866abd4fb4dcb(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_transform_NodeNumberNode$method$fromMatches$d09ae2cf157ddd0f(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_xml_transform_NodeNumberNode$method$getIndex$b9d463639d011209(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_NodeNumberNode$method_info$clone$b8a038f4254cb648;
extern _jc_method _jc_gnu_xml_transform_NodeNumberNode$method_info$compute$51e66c80abac24fa;
extern _jc_method _jc_gnu_xml_transform_NodeNumberNode$method_info$countMatches$09e866abd4fb4dcb;
extern _jc_method _jc_gnu_xml_transform_NodeNumberNode$method_info$fromMatches$d09ae2cf157ddd0f;
extern _jc_method _jc_gnu_xml_transform_NodeNumberNode$method_info$getIndex$b9d463639d011209;

// Virtual methods structure
struct _jc_gnu_xml_transform_NodeNumberNode$vmethods {
	struct _jc_gnu_xml_transform_TemplateNode$object	*(*clone$b8a038f4254cb648)(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
	_jc_int_array	*(*compute$51e66c80abac24fa)(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	jboolean	(*countMatches$09e866abd4fb4dcb)(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*fromMatches$d09ae2cf157ddd0f)(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jint	(*getIndex$b9d463639d011209)(_jc_env *, struct _jc_gnu_xml_transform_NodeNumberNode$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_NodeNumberNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplateNode$vmethods	gnu_xml_transform_TemplateNode;
	_jc_gnu_xml_transform_AbstractNumberNode$vmethods	gnu_xml_transform_AbstractNumberNode;
	_jc_gnu_xml_transform_NodeNumberNode$vmethods	gnu_xml_transform_NodeNumberNode;
};

// Vtype
struct _jc_gnu_xml_transform_NodeNumberNode$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_NodeNumberNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_NodeNumberNode$sub_refs {
	struct _jc_gnu_xml_xpath_Pattern$object	*count;
	struct _jc_gnu_xml_xpath_Pattern$object	*from;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_NodeNumberNode$refs {
    _jc_gnu_xml_transform_NodeNumberNode$sub_refs	gnu_xml_transform_NodeNumberNode;
    _jc_gnu_xml_transform_AbstractNumberNode$sub_refs	gnu_xml_transform_AbstractNumberNode;
    _jc_gnu_xml_transform_TemplateNode$sub_refs	gnu_xml_transform_TemplateNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_NodeNumberNode$sub_nonrefs {
	jint	level;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_NodeNumberNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	gnu_xml_transform_TemplateNode;
    _jc_gnu_xml_transform_AbstractNumberNode$sub_nonrefs	gnu_xml_transform_AbstractNumberNode;
    _jc_gnu_xml_transform_NodeNumberNode$sub_nonrefs	gnu_xml_transform_NodeNumberNode;
};

// Object instance structure
struct _jc_gnu_xml_transform_NodeNumberNode$object {
	_jc_gnu_xml_transform_NodeNumberNode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_NodeNumberNode$vtype	*vtype;
	_jc_gnu_xml_transform_NodeNumberNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_NodeNumberNode$vtype _jc_gnu_xml_transform_NodeNumberNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_NodeNumberNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_NodeNumberNode$class_object;

#endif	/* _JC_gnu_xml_transform_NodeNumberNode_H_ */
